Intro
-----

BlazeWeb (formerly pysmvt) is a WSGI web framework library designed to be
relatively "light weight", but with a powerful plug-in and override architecture
that facilitates modularized development.

Questions & Comments
---------------------

Please visit: http://groups.google.com/group/blazelibs

Current Status
---------------

The code stays pretty stable, but some of the API will probably
change in the future.

The `BlazeWeb tip <http://bitbucket.org/blazelibs/blazeweb/get/tip.zip#egg=BlazeWeb-dev>`_
is installable via `easy_install` with ``easy_install BlazeWeb==dev``
